#' @keywords internal
"_PACKAGE"

#' @importFrom ggplot2 aes after_stat
#' @importFrom rlang .data
#' @importFrom grDevices terrain.colors rgb col2rgb grey
#' @importFrom tibble as_tibble
#' @importFrom cli qty
NULL

#' @export
ggplot2::aes

#' @export
ggplot2::after_stat
